Learn R Programming

recorder (version 0.8.2)

ignore: Ignore Certain Test Results

Description

Ignores certain test results in accordance with user inputs.

Usage

ignore(tests, variables_newdata, ignore_tests = NULL,
  ignore_cols = NULL, ignore_combinations = NULL)

Arguments

tests

list test results.

variables_newdata

character names of variables in new data.

ignore_tests

character ignore test results from tests with these names.

ignore_cols

character ignore test results from tests of columns with these names.

ignore_combinations

list ignore test results from specific tests of specific columns.

Value

list only the relevant test results.

Details

Look up the descriptions and other meta data of the available validation tests with get_tests_meta_data.