Learn R Programming

recorder (version 0.8.2)

ignore_combinations: Ignore Test Results from Specific Tests of Specific Columns

Description

Ignore Test Results from Specific Tests of Specific Columns

Usage

ignore_combinations(tests, combinations, variables_newdata)

Arguments

tests

list test results.

combinations

list combinations of tests and columns from which test results should be ignored.

variables_newdata

character names of variables in new data.

Value

list test results after removals.