Ignores certain test results in accordance with user inputs.
ignore(tests, variables_newdata, ignore_tests = NULL,
ignore_cols = NULL, ignore_combinations = NULL)list test results.
character names of variables in new data.
character ignore test results from tests with
these names.
character ignore test results from tests of
columns with these names.
list ignore test results from specific
tests of specific columns.
list only the relevant test results.
Look up the descriptions and other meta data of the available
validation tests with get_tests_meta_data.