ignore_combinations: Ignore Test Results from Specific Tests of Specific Columns
Description
Ignore Test Results from Specific Tests of Specific Columns
Usage
ignore_combinations(tests, combinations, variables_newdata)
Arguments
combinations
list combinations of tests and columns from which
test results should be ignored.
variables_newdata
character names of variables in new data.
Value
list test results after removals.